@@ -148,7 +148,7 @@ write_the_docs <- function(package_directory, file_name = package_directory,
     rcmd_args <- c("--no-preview", "--internals", "--force",
                    paste0("--title=", pdf_title), paste0("--output=", pdf_path),
                    man_directory)
-    call_pdf <- withr::with_dir(tempdir(),
+    call_pdf <- withr::with_dir(output_directory,
                                 callr::rcmd_safe("Rd2pdf", rcmd_args)
                                 )
     if (! as.logical(call_pdf[["status"]])) status[["pdf_path"]]  <- pdf_path
